Clazz.declarePackage("JSV.common");
Clazz.declareInterface(JSV.common, "XYScaleConverter");
;//5.0.1-v2 Tue Feb 20 10:58:47 CST 2024
